@@ -1,5 +1,5 @@
 from hyperliquid.api import API
-from hyperliquid.utils.types import Any, Callable, Meta, Optional, Subscription, cast, Cloid
+from hyperliquid.utils.types import Any, Callable, Meta, SpotMeta, Optional, Subscription, cast, Cloid
 from hyperliquid.websocket_manager import WebsocketManager
 
 
@@ -54,6 +54,9 @@ class Info(API):
         """
         return self.post("/info", {"type": "clearinghouseState", "user": address})
 
+    def spot_user_state(self, address: str) -> Any:
+        return self.post("/info", {"type": "spotClearinghouseState", "user": address})
+
     def open_orders(self, address: str) -> Any:
         """Retrieve a user's open orders.
 
@@ -152,7 +155,7 @@ class Info(API):
         return self.post("/info", {"type": "userFills", "user": address})
 
     def meta(self) -> Meta:
-        """Retrieve exchange metadata
+        """Retrieve exchange perp metadata
 
         POST /info
 
@@ -169,6 +172,32 @@ class Info(API):
         """
         return cast(Meta, self.post("/info", {"type": "meta"}))
 
+    def spot_meta(self) -> SpotMeta:
+        """Retrieve exchange spot metadata
+
+        POST /info
+
+        Returns:
+            {
+                tokens: [
+                    {
+                        name: str,
+                        szDecimals: int,
+                        weiDecimals: int
+                    },
+                    ...
+                ],
+                universe: [
+                    {
+                        name: str,
+                        tokens: [int, int]
+                    },
+                    ...
+                ]
+            }
+        """
+        return cast(SpotMeta, self.post("/info", {"type": "spotMeta"}))
+
     def funding_history(self, coin: str, startTime: int, endTime: Optional[int] = None) -> Any:
         """Retrieve funding history for a given coin
 
@@ -272,6 +301,49 @@ class Info(API):
         req = {"coin": coin, "interval": interval, "startTime": startTime, "endTime": endTime}
         return self.post("/info", {"type": "candleSnapshot", "req": req})
 
+    def user_fees(self, address: str) -> Any:
+        """Retrieve the volume of trading activity associated with a user.
+        POST /info
+        Args:
+            address (str): Onchain address in 42-character hexadecimal format;
+                            e.g. 0x0000000000000000000000000000000000000000.
+        Returns:
+            {
+                activeReferralDiscount: float string,
+                dailyUserVlm: [
+                    {
+                        date: str,
+                        exchange: str,
+                        userAdd: float string,
+                        userCross: float string
+                    },
+                ],
+                feeSchedule: {
+                    add: float string,
+                    cross: float string,
+                    referralDiscount: float string,
+                    tiers: {
+                        mm: [
+                            {
+                                add: float string,
+                                makerFractionCutoff: float string
+                            },
+                        ],
+                        vip: [
+                            {
+                                add: float string,
+                                cross: float string,
+                                ntlCutoff: float string
+                            },
+                        ]
+                    }
+                },
+                userAddRate: float string,
+                userCrossRate: float string
+            }
+        """
+        return self.post("/info", {"type": "userFees", "user": address})
+
     def query_order_by_oid(self, user: str, oid: int) -> Any:
         return self.post("/info", {"type": "orderStatus", "user": user, "oid": oid})
 
@@ -281,6 +353,9 @@ class Info(API):
     def query_referral_state(self, user: str) -> Any:
         return self.post("/info", {"type": "referral", "user": user})
 
+    def query_sub_accounts(self, user: str) -> Any:
+        return self.post("/info", {"type": "subAccounts", "user": user})
+
     def subscribe(self, subscription: Subscription, callback: Callable[[Any], None]) -> int:
         if self.ws_manager is None:
             raise RuntimeError("Cannot call subscribe since skip_ws was used")
