@@ -27,10 +27,11 @@ OrderRequest = TypedDict(
     },
     total=False,
 )
+OidOrCloid = Union[int, Cloid]
 ModifyRequest = TypedDict(
     "ModifyRequest",
     {
-        "oid": int,
+        "oid": OidOrCloid,
         "order": OrderRequest,
     },
     total=False,
@@ -135,20 +136,18 @@ def sign_l1_action(wallet, action, active_pool, nonce, is_mainnet):
     return sign_inner(wallet, data)
 
 
-def sign_usd_transfer_action(wallet, message, is_mainnet):
+def sign_user_signed_action(wallet, action, payload_types, primary_type, is_mainnet):
+    action["signatureChainId"] = "0x66eee"
+    action["hyperliquidChain"] = "Mainnet" if is_mainnet else "Testnet"
     data = {
         "domain": {
-            "name": "Exchange",
+            "name": "HyperliquidSignTransaction",
             "version": "1",
-            "chainId": 42161 if is_mainnet else 421614,
+            "chainId": 421614,
             "verifyingContract": "0x0000000000000000000000000000000000000000",
         },
         "types": {
-            "UsdTransferSignPayload": [
-                {"name": "destination", "type": "string"},
-                {"name": "amount", "type": "string"},
-                {"name": "time", "type": "uint64"},
-            ],
+            primary_type: payload_types,
             "EIP712Domain": [
                 {"name": "name", "type": "string"},
                 {"name": "version", "type": "string"},
@@ -156,63 +155,55 @@ def sign_usd_transfer_action(wallet, message, is_mainnet):
                 {"name": "verifyingContract", "type": "address"},
             ],
         },
-        "primaryType": "UsdTransferSignPayload",
-        "message": message,
+        "primaryType": primary_type,
+        "message": action,
     }
     return sign_inner(wallet, data)
 
 
-def sign_withdraw_from_bridge_action(wallet, message, is_mainnet):
-    data = {
-        "domain": {
-            "name": "Exchange",
-            "version": "1",
-            "chainId": 42161 if is_mainnet else 421614,
-            "verifyingContract": "0x0000000000000000000000000000000000000000",
-        },
-        "types": {
-            "WithdrawFromBridge2SignPayload": [
-                {"name": "destination", "type": "string"},
-                {"name": "usd", "type": "string"},
-                {"name": "time", "type": "uint64"},
-            ],
-            "EIP712Domain": [
-                {"name": "name", "type": "string"},
-                {"name": "version", "type": "string"},
-                {"name": "chainId", "type": "uint256"},
-                {"name": "verifyingContract", "type": "address"},
-            ],
-        },
-        "primaryType": "WithdrawFromBridge2SignPayload",
-        "message": message,
-    }
-    return sign_inner(wallet, data)
+def sign_usd_transfer_action(wallet, action, is_mainnet):
+    return sign_user_signed_action(
+        wallet,
+        action,
+        [
+            {"name": "hyperliquidChain", "type": "string"},
+            {"name": "destination", "type": "string"},
+            {"name": "amount", "type": "string"},
+            {"name": "time", "type": "uint64"},
+        ],
+        "HyperliquidTransaction:UsdSend",
+        is_mainnet,
+    )
 
 
-def sign_agent(wallet, agent, is_mainnet):
-    data = {
-        "domain": {
-            "name": "Exchange",
-            "version": "1",
-            "chainId": 42161 if is_mainnet else 421614,
-            "verifyingContract": "0x0000000000000000000000000000000000000000",
-        },
-        "types": {
-            "Agent": [
-                {"name": "source", "type": "string"},
-                {"name": "connectionId", "type": "bytes32"},
-            ],
-            "EIP712Domain": [
-                {"name": "name", "type": "string"},
-                {"name": "version", "type": "string"},
-                {"name": "chainId", "type": "uint256"},
-                {"name": "verifyingContract", "type": "address"},
-            ],
-        },
-        "primaryType": "Agent",
-        "message": agent,
-    }
-    return sign_inner(wallet, data)
+def sign_withdraw_from_bridge_action(wallet, action, is_mainnet):
+    return sign_user_signed_action(
+        wallet,
+        action,
+        [
+            {"name": "hyperliquidChain", "type": "string"},
+            {"name": "destination", "type": "string"},
+            {"name": "amount", "type": "string"},
+            {"name": "time", "type": "uint64"},
+        ],
+        "HyperliquidTransaction:Withdraw",
+        is_mainnet,
+    )
+
+
+def sign_agent(wallet, action, is_mainnet):
+    return sign_user_signed_action(
+        wallet,
+        action,
+        [
+            {"name": "hyperliquidChain", "type": "string"},
+            {"name": "agentAddress", "type": "address"},
+            {"name": "agentName", "type": "string"},
+            {"name": "nonce", "type": "uint64"},
+        ],
+        "HyperliquidTransaction:ApproveAgent",
+        is_mainnet,
+    )
 
 
 def sign_inner(wallet, data):
